==> wsclient-8.0.4-1-sources.jar: org/hpccsystems/ws/client/wrappers/gen/wstopology/TpGetServicePluginsRequestWrapper.java <==
package org.hpccsystems.ws.client.wrappers.gen.wstopology;



/*******************************************************************************
 * HPCC SYSTEMS software Copyright (C) 2019 HPCC Systems.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *******************************************************************************/

/**
 * Generated Axis2 ADB stub class wrapper
 * Class name: TpGetServicePluginsRequestWrapper
 * Wraps class: org.hpccsystems.ws.client.gen.axis2.wstopology.v1_30.TpGetServicePluginsRequest
 * Output package : org.hpccsystems.ws.client.wrappers.gen.wstopology
 * TimeStamp: 2020-09-23T21:40:52.958Z
 */
public class TpGetServicePluginsRequestWrapper
{

	public TpGetServicePluginsRequestWrapper() {}

	public org.hpccsystems.ws.client.gen.axis2.wstopology.v1_30.TpGetServicePluginsRequest getRaw()
	{
		org.hpccsystems.ws.client.gen.axis2.wstopology.v1_30.TpGetServicePluginsRequest raw = new org.hpccsystems.ws.client.gen.axis2.wstopology.v1_30.TpGetServicePluginsRequest();
		return raw;
	}


}

==> wsclient-9.4.24-1-sources.jar: org/hpccsystems/ws/client/wrappers/gen/wstopology/TpGetServicePluginsRequestWrapper.java <==
package org.hpccsystems.ws.client.wrappers.gen.wstopology;

/*******************************************************************************
 * HPCC SYSTEMS software Copyright (C) 2021 HPCC Systems.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *******************************************************************************/

/**
 * Generated Axis2 ADB stub class wrapper
 * Class name: TpGetServicePluginsRequestWrapper
 * Wraps class: org.hpccsystems.ws.client.gen.axis2.wstopology.latest.TpGetServicePluginsRequest
 * Output package : org.hpccsystems.ws.client.wrappers.gen.wstopology
 */
public class TpGetServicePluginsRequestWrapper
{

    public TpGetServicePluginsRequestWrapper() {}

    public org.hpccsystems.ws.client.gen.axis2.wstopology.latest.TpGetServicePluginsRequest getRaw()
    {
        org.hpccsystems.ws.client.gen.axis2.wstopology.latest.TpGetServicePluginsRequest raw = new org.hpccsystems.ws.client.gen.axis2.wstopology.latest.TpGetServicePluginsRequest();
        return raw;
    }


}
